/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Swarco Traffic Systems GmbH
 * Entwicklung
 * Adolf-Dambach-Strae
 * D-76571 Gaggenau
 * Phone: +49 (0)7225-64-0
 * Fax: +49 (0)7225-64-300
 * mailto: office.sts@swarco.de
 */

package de.bsvrz.ste.stealgsba.algorithmen.lib;

import java.util.List;
import java.util.Vector;

import de.bsvrz.dav.daf.main.ClientDavInterface;
import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.config.ConfigurationObject;
import de.bsvrz.dav.daf.main.config.SystemObject;
import de.bsvrz.ste.stealgsba.algorithmusrahmen.AnzeigenDatensatz;
import de.bsvrz.ste.stealgsba.algorithmusrahmen.EinzelMassnahmeAlternative;
import de.bsvrz.ste.stealgsba.algorithmusrahmen.Massnahmenanforderung;

/**
 * Kommentar 
 *
 * @version $Revision: 1.4 $ / $Date: 2015/09/02 12:50:04 $ / ($Author: Asal $)
 *
 * @author Swarco Traffic Systems GmbH
 * @author Rolf Asal
 *
 */
public class TestTools
{

	/**
	 * Diese Methode fllt den bergebenen Datensatz der Attributgruppe <code>atg.sswSbaEinzelMassnahme</code>.
	 * 
	 * @param massnahmenanforderung Daten der Massnahmeanforderung.
	 * @param dataNeu zu fllender Datensatz.
	 */
	public static void fuelleAtgEinzelMassnahme(Massnahmenanforderung massnahmenanforderung, Data dataNeu)
	{
		if (massnahmenanforderung != null)
		{				
			dataNeu.getArray("Aktiv").setLength(0);
			dataNeu.getArray("Inaktiv").setLength(0);
			
			Vector<EinzelMassnahmeAlternative> vema = massnahmenanforderung.getEinzelMassnahmeAlternative();
			if (vema.size() > 0)
			{
				EinzelMassnahmeAlternative ema = vema.get(0);
				Vector<AnzeigenDatensatz> anzeigenDatensaetze = ema.getEinzelMassnahmeAlternative();

				dataNeu.getArray("Aktiv").setLength(1);
				Data elementAktiv = dataNeu.getArray("Aktiv").getItem(0);
				
				for (int i = 0; i < anzeigenDatensaetze.size(); i++)
				{
					AnzeigenDatensatz azds = anzeigenDatensaetze.get(i);
					
					elementAktiv.getArray("AnzeigenDatenstze").setLength(i+1);
					
					Data elementAnzeigenDatensatz = elementAktiv.getArray("AnzeigenDatenstze").getItem(i);
					
					// AnzeigenDatensatz
					elementAnzeigenDatensatz.getItem("AnzeigenDatensatz").getScaledValue("notwendig").setText((azds.isNotwendig()) ? "Ja" : "Nein");
					elementAnzeigenDatensatz.getItem("AnzeigenDatensatz").getScaledValue("absolutNotwendig").setText((azds.isAbsolutNotwendig()) ? "Ja" : "Nein");
					elementAnzeigenDatensatz.getItem("AnzeigenDatensatz").getUnscaledValue("Prioritt").set(azds.getPrioritt());
					elementAnzeigenDatensatz.getItem("AnzeigenDatensatz").getScaledValue("verschiebbarVorgnger").set(azds.getVerschiebbarVorgnger());
					elementAnzeigenDatensatz.getItem("AnzeigenDatensatz").getScaledValue("verschiebbarNachfolger").set(azds.getVerschiebbarNachfolger());
					
					// Anzeigereferenz
					elementAnzeigenDatensatz.getReferenceValue("Anzeige").setSystemObject(azds.getAnzeige());

					// WVZInhalt
					elementAnzeigenDatensatz.getItem("WVZInhalt").getReferenceValue("AnzeigeInhalt").setSystemObject(azds.getAnzeigeInhalt());
					elementAnzeigenDatensatz.getItem("WVZInhalt").getScaledValue("Blinken").setText("Nein");
					elementAnzeigenDatensatz.getItem("WVZInhalt").getScaledValue("Blinktakt").set(0);
					elementAnzeigenDatensatz.getItem("WVZInhalt").getArray("GrafikDarstellungen").setLength(0);
					elementAnzeigenDatensatz.getItem("WVZInhalt").getReferenceValue("Wechseltext").setText("undefiniert");
					
					elementAnzeigenDatensatz.getItem("WVZInhalt").getItem("DynamischerWechseltext").getReferenceValue("Font").setText("undefiniert");
					elementAnzeigenDatensatz.getItem("WVZInhalt").getItem("DynamischerWechseltext").getScaledValue("TextAusrichtung").setText("Undefiniert");
					elementAnzeigenDatensatz.getItem("WVZInhalt").getItem("DynamischerWechseltext").getArray("Textdefinition").setLength(0);
				}
			}
		}
	}

	/**
	 * Diese Methode fllt den bergebenen Datensatz der Attributgruppe <code>atg.sswSbaEinzelMassnahme</code>.
	 * 
	 * @param massnahmenanforderung Daten der Massnahmeanforderung.
	 * @param dataNeu zu fllender Datensatz.
	 */
	public static void fuelleAtgMassnahmenAnforderung(Massnahmenanforderung massnahmenanforderung, Data dataNeu)
	{
		if (massnahmenanforderung != null)
		{				
			dataNeu.getReferenceValue("Ursacheneinheit").setSystemObject(massnahmenanforderung.getReferenz());
			dataNeu.getScaledValue("spontan").setText("Ja");
			dataNeu.getScaledValue("lschen").setText("Nein");
			
			dataNeu.getItem("BenutzerInfo").getUnscaledValue("nummer").set(0);
			dataNeu.getItem("BenutzerInfo").getTextValue("absenderAlgorithmus").setText(massnahmenanforderung.getAbsenderAlgorithmus());
			dataNeu.getItem("BenutzerInfo").getReferenceValue("absenderApplikation").setText("" + massnahmenanforderung.getAbsenderApplikation());
			dataNeu.getItem("BenutzerInfo").getReferenceValue("empfnger").setSystemObject(massnahmenanforderung.getEmpfaenger());
						
			Vector<EinzelMassnahmeAlternative> vema = massnahmenanforderung.getEinzelMassnahmeAlternative();
			if (vema.size() > 0)
			{
				EinzelMassnahmeAlternative ema = vema.get(0);
				Vector<AnzeigenDatensatz> anzeigenDatensaetze = ema.getEinzelMassnahmeAlternative();

				dataNeu.getArray("EinzelMassnahmeAlternative").setLength(1);
				Data elementAktiv = dataNeu.getArray("EinzelMassnahmeAlternative").getItem(0);
				
				for (int i = 0; i < anzeigenDatensaetze.size(); i++)
				{
					AnzeigenDatensatz azds = anzeigenDatensaetze.get(i);
					
					elementAktiv.getArray("AnzeigenDatenstze").setLength(i+1);
					
					Data elementAnzeigenDatensatz = elementAktiv.getArray("AnzeigenDatenstze").getItem(i);
					
					// AnzeigenDatensatz
					elementAnzeigenDatensatz.getItem("AnzeigenDatensatz").getScaledValue("notwendig").setText((azds.isNotwendig()) ? "Ja" : "Nein");
					elementAnzeigenDatensatz.getItem("AnzeigenDatensatz").getScaledValue("absolutNotwendig").setText((azds.isAbsolutNotwendig()) ? "Ja" : "Nein");
					elementAnzeigenDatensatz.getItem("AnzeigenDatensatz").getUnscaledValue("Prioritt").set(azds.getPrioritt());
					elementAnzeigenDatensatz.getItem("AnzeigenDatensatz").getScaledValue("verschiebbarVorgnger").set(azds.getVerschiebbarVorgnger());
					elementAnzeigenDatensatz.getItem("AnzeigenDatensatz").getScaledValue("verschiebbarNachfolger").set(azds.getVerschiebbarNachfolger());
					
					// Anzeigereferenz
					elementAnzeigenDatensatz.getReferenceValue("Anzeige").setSystemObject(azds.getAnzeige());

					// WVZInhalt
					elementAnzeigenDatensatz.getItem("WVZInhalt").getReferenceValue("AnzeigeInhalt").setSystemObject(azds.getAnzeigeInhalt());
					elementAnzeigenDatensatz.getItem("WVZInhalt").getScaledValue("Blinken").setText("Nein");
					elementAnzeigenDatensatz.getItem("WVZInhalt").getScaledValue("Blinktakt").set(0);
					elementAnzeigenDatensatz.getItem("WVZInhalt").getArray("GrafikDarstellungen").setLength(0);
					elementAnzeigenDatensatz.getItem("WVZInhalt").getReferenceValue("Wechseltext").setText("undefiniert");
					
					elementAnzeigenDatensatz.getItem("WVZInhalt").getItem("DynamischerWechseltext").getReferenceValue("Font").setText("undefiniert");
					elementAnzeigenDatensatz.getItem("WVZInhalt").getItem("DynamischerWechseltext").getScaledValue("TextAusrichtung").setText("Undefiniert");
					elementAnzeigenDatensatz.getItem("WVZInhalt").getItem("DynamischerWechseltext").getArray("Textdefinition").setLength(0);
				}
			}
		}
	}

	/**
	 * Diese Methode fllt den bergebenen Datensatz der Attributgruppe <code>atg.sswSbaUrsachenEinheit</code>.
	 * @param dataNeu zu fllender Datensatz.
	 * @param status zu setzende Statusbercksichtigung.
	 * @param semiautomatik zu setzender Wert fr die Semiautomatik.
	 */
	public static void fuelleAtgUrsachenEinheit(Data dataNeu, String status, boolean semiautomatik, int tMinEin, int tMinAus, int tMinStoer)
	{
		if (status != null)
			dataNeu.getScaledValue("StatusBercksichtigung").setText(status);
		else
			dataNeu.getScaledValue("StatusBercksichtigung").setText("automatik");
			
		dataNeu.getReferenceValue("AspektVerwendung").setText("undefiniert");
		dataNeu.getScaledValue("Semiautomatik").setText((semiautomatik) ? "Ja": "Nein");
		dataNeu.getScaledValue("Bearbeitung").setText("Ja");
		dataNeu.getItem("Mindeststandzeit").getTimeValue("tMinEin").setSeconds(tMinEin);
		dataNeu.getItem("Mindeststandzeit").getTimeValue("tMinAus").setSeconds(tMinAus);
		dataNeu.getItem("Mindeststandzeit").getTimeValue("tMinStr").setSeconds(tMinStoer);
	}
	/**
	 * Diese Methode fllt den bergebenen Datensatz der Attributgruppe <code>atg.sswSbaUrsachenEinheit</code>.
	 * @param status Wert Statusbercksichtigung.
	 * @param dataNeu zu fllender Datensatz.
	 */
	public static void fuelleAtgUrsachenEinheit(Data dataNeu, String status)
	{
		fuelleAtgUrsachenEinheit(dataNeu, status, false, 0, 0, 0);
	}
	/**
	 * Diese Methode fllt den bergebenen Datensatz der Attributgruppe <code>atg.sswSbaUrsachenEinheit</code>.
	 * @param dataNeu zu fllender Datensatz.
	 */
	public static void fuelleAtgUrsachenEinheit(Data dataNeu)
	{
		fuelleAtgUrsachenEinheit(dataNeu, null, false, 0, 0, 0);
	}
	
	/**
	 * Diese Methode fllt den bergebenen Datensatz der Attributgruppe <code>atg.sswSbaUeMqZuordnung</code>.
	 * @param messQuerschnitte Liste der Messquerschnitte.
	 * @param dataNeu zu fllender Datensatz.
	 */
	public static void fuelleAtgMqZuordnung(List<SystemObject> messQuerschnitte, Data dataNeu)
	{
		for (int i = 0; i < messQuerschnitte.size(); i++)
		{
			dataNeu.getArray("MessQuerschnitt").setLength(i+1);
			dataNeu.getArray("MessQuerschnitt").getReferenceValue(i).setSystemObject(messQuerschnitte.get(i));
			
		}
		
	}

	/**
	 * Diese Methode fllt den bergebenen Datensatz der Attributgruppe <code>atg.sswSbaUeUfdmsZuordnung</code>.
	 * @param ufdms Liste der Umfelddatenmessstellen.
	 * @param dataNeu zu fllender Datensatz.
	 */
	public static void fuelleAtgUfdmsZuordnung(List<SystemObject> ufdms, SystemObject ufds, Data dataNeu)
	{
		for (int i = 0; i < ufdms.size(); i++)
		{
			dataNeu.getArray("UmfeldDatenMessStelle").setLength(i+1);
			dataNeu.getArray("UmfeldDatenMessStelle").getReferenceValue(i).setSystemObject(ufdms.get(i));
			
			if (ufds != null)
				dataNeu.getReferenceValue("UmfeldDatenSensorTagNacht").setSystemObject(ufds);
			else
				dataNeu.getReferenceValue("UmfeldDatenSensorTagNacht").setText("undefiniert");				
		}		
	}

	/**
	 * Diese Methode fllt den bergebenen Datensatz der Attributgruppe <code>atg.sswSbaUeUfdsZuordnung</code>.
	 * @param ufdms Liste der Umfelddatensensoren.
	 * @param dataNeu zu fllender Datensatz.
	 */
	public static void fuelleAtgUfdsZuordnung(List<SystemObject> ufdms, Data dataNeu)
	{
		for (int i = 0; i < ufdms.size(); i++)
		{
			dataNeu.getArray("UmfeldDatenSensor").setLength(i+1);
			dataNeu.getArray("UmfeldDatenSensor").getReferenceValue(i).setSystemObject(ufdms.get(i));
			
		}
		
	}

	/**
	 * Diese Methode fllt den bergebenen Datensatz der Attributgruppe <code>atg.strfallZustand</code>.
	 * @param situation Situation Strfallzustand.
	 * @param dataNeu zu fllender Datensatz.
	 */
	public static void fuelleAtgStoerfallZustand(int situation, Data dataNeu)
	{
		dataNeu.getTimeValue("T").setSeconds(60);
		dataNeu.getUnscaledValue("Situation").set(situation);
		dataNeu.getTimeValue("Horizont").setSeconds(0);
		dataNeu.getItem("Gte").getScaledValue("Index").set(1.0);
		dataNeu.getItem("Gte").getScaledValue("Verfahren").setText("Standard");
	}

	public static void fuelleAtgVerkehrsDatenKurzZeitMq(int qkfz, int vkfz, int qb, int aLkw, int b, Data dataNeu)
	{
		fuelleAtgVerkehrsDatenKurzZeitMq(qkfz, vkfz, -1, -1, -1, -1, qb, aLkw, b, dataNeu);
	}
	
	public static void fuelleAtgVerkehrsDatenKurzZeitMq(int qkfz, int vkfz, int qb, int aLkw, Data dataNeu)
	{
		fuelleAtgVerkehrsDatenKurzZeitMq(qkfz, vkfz, -1, -1, -1, -1, qb, aLkw, -1, dataNeu);
	}
	
	public static void fuelleAtgVerkehrsDatenKurzZeitMq(int qkfz, int vkfz, int qlkw, int vlkw, int qpkw, int vpkw, int qb, int alkw, Data dataNeu)
	{
		fuelleAtgVerkehrsDatenKurzZeitMq(qkfz, vkfz, qlkw, vlkw, qpkw, vpkw, qb, alkw, -1, dataNeu);
	}

	public static void fuelleAtgVerkehrsDatenKurzZeitMq(int qkfz, int vkfz, int qlkw, int vlkw, int qpkw, int vpkw, int qb, int aLkw, int b, Data dataNeu)
	{
		Data element = dataNeu.getItem("QKfz");
		setzeWert(qkfz, element);
		element = dataNeu.getItem("VKfz");
		setzeWert(vkfz, element);
		element = dataNeu.getItem("QLkw");
		setzeWert(qlkw, element);
		element = dataNeu.getItem("VLkw");
		setzeWert(vlkw, element);		
		element = dataNeu.getItem("QPkw");
		setzeWert(qpkw, element);
		element = dataNeu.getItem("VPkw");
		setzeWert(vpkw, element);				
		element = dataNeu.getItem("B");
		setzeWert(b, element);
		element = dataNeu.getItem("BMax");
		setzeWert(-1, element);
		element = dataNeu.getItem("SKfz");
		setzeWert(-1, element);
		element = dataNeu.getItem("VgKfz");
		setzeWert(-1, element);
		element = dataNeu.getItem("ALkw");
		setzeWert(aLkw, element);
		element = dataNeu.getItem("KKfz");
		setzeWert(-1, element);
		element = dataNeu.getItem("KLkw");
		setzeWert(-1, element);
		element = dataNeu.getItem("KPkw");
		setzeWert(-1, element);
		element = dataNeu.getItem("QB");
		setzeWert(qb, element);
		element = dataNeu.getItem("KB");
		setzeWert(-1, element);
		element = dataNeu.getItem("VDelta");
		setzeWert(-1, element);
	}

	public static void fuelleAtgVerkehrsDatenKurzZeitTrendExtraPolationMq(int qkfz, int vkfz, int vpkw, int qb, int kkfz, int qLkw, Data dataNeu)
	{
		Data element = dataNeu.getItem("QKfzP");
		setzeWert(qkfz, element);
		element = dataNeu.getItem("VKfzP");
		setzeWert(vkfz, element);
		element = dataNeu.getItem("QLkwP");
		setzeWert(qLkw, element);
		element = dataNeu.getItem("VLkwP");
		setzeWert(-1, element);		
		element = dataNeu.getItem("QPkwP");
		setzeWert(-1, element);
		element = dataNeu.getItem("VPkwP");
		setzeWert(vpkw, element);				
		element = dataNeu.getItem("ALkwP");
		setzeWert(-1, element);
		element = dataNeu.getItem("KKfzP");
		setzeWert(kkfz, element);
		element = dataNeu.getItem("KLkwP");
		setzeWert(-1, element);
		element = dataNeu.getItem("KPkwP");
		setzeWert(-1, element);
		element = dataNeu.getItem("QBP");
		setzeWert(qb, element);
		element = dataNeu.getItem("KBP");
		setzeWert(-1, element);
	}

	public static void fuelleAtgVerkehrsDatenKurzZeitIntervall(int qkfz, int vkfz, int qlkw, int vlkw, int qpkw, int vpkw, int skfz, Data dataNeu)
	{
		fuelleAtgVerkehrsDatenKurzZeitIntervall(qkfz, vkfz, qlkw, vlkw, qpkw, vpkw, skfz, -1, dataNeu);
	}
	public static void fuelleAtgVerkehrsDatenKurzZeitIntervall(int qkfz, int vkfz, int qlkw, int vlkw, int qpkw, int vpkw, int skfz, long tNetto, Data dataNeu)
	{
		dataNeu.getTimeValue("T").setSeconds(60);
		dataNeu.getScaledValue("ArtMittelwertbildung").setText("unbekannt");
		
		Data element = dataNeu.getItem("qKfz");
		setzeWert(qkfz, element);
		element = dataNeu.getItem("vKfz");
		setzeWert(vkfz, element);
		element = dataNeu.getItem("qLkw");
		setzeWert(qlkw, element);
		element = dataNeu.getItem("vLkw");
		setzeWert(vlkw, element);		
		element = dataNeu.getItem("qPkw");
		setzeWert(qpkw, element);
		element = dataNeu.getItem("vPkw");
		setzeWert(vpkw, element);				
		element = dataNeu.getItem("b");
		setzeWert(-1, element);
		element = dataNeu.getItem("tNetto");
		setzeWert(tNetto, element);
		element = dataNeu.getItem("sKfz");
		setzeWert(skfz, element);
		element = dataNeu.getItem("vgKfz");
		setzeWert(-1, element);
	}
	public static void fuelleAtgVerkehrsDatenKurzZeitFs(int qkfz, int vkfz, int qlkw, int vlkw, int qpkw, int vpkw, int skfz, int b, Data dataNeu)
	{
		fuelleAtgVerkehrsDatenKurzZeitFs(qkfz, vkfz, qlkw, vlkw, qpkw, vpkw, skfz, b, -1, dataNeu);
	}
	public static void fuelleAtgVerkehrsDatenKurzZeitFs(int vgkfz, Data dataNeu)
	{
		fuelleAtgVerkehrsDatenKurzZeitFs(-1, vgkfz, dataNeu);
	}
	
	public static void fuelleAtgVerkehrsDatenKurzZeitFs(int qkfz, int vkfz, int qlkw, int vlkw, int qpkw, int vpkw, int skfz, int b, int qb, Data dataNeu)
	{
		dataNeu.getTimeValue("T").setSeconds(60);
		
		Data element = dataNeu.getItem("qKfz");
		setzeWert(qkfz, element);
		element = dataNeu.getItem("vKfz");
		setzeWert(vkfz, element);
		element = dataNeu.getItem("qLkw");
		setzeWert(qlkw, element);
		element = dataNeu.getItem("vLkw");
		setzeWert(vlkw, element);		
		element = dataNeu.getItem("qPkw");
		setzeWert(qpkw, element);
		element = dataNeu.getItem("vPkw");
		setzeWert(vpkw, element);				
		element = dataNeu.getItem("b");
		setzeWert(b, element);
		element = dataNeu.getItem("sKfz");
		setzeWert(skfz, element);
		element = dataNeu.getItem("vgKfz");
		setzeWert(-1, element);
		element = dataNeu.getItem("aLkw");
		setzeWert(-1, element);
		element = dataNeu.getItem("kKfz");
		setzeWert(-1, element);
		element = dataNeu.getItem("kLkw");
		setzeWert(-1, element);
		element = dataNeu.getItem("kPkw");
		setzeWert(-1, element);
		element = dataNeu.getItem("qB");
		setzeWert(qb, element);
		element = dataNeu.getItem("kB");
		setzeWert(-1, element);
	}

	public static void fuelleAtgVerkehrsDatenKurzZeitFs(int qkfz, int vgkfz, Data dataNeu)
	{
		dataNeu.getTimeValue("T").setSeconds(60);
		
		Data element = dataNeu.getItem("qKfz");
		setzeWert(qkfz, element);
		element = dataNeu.getItem("vKfz");
		setzeWert(-1, element);
		element = dataNeu.getItem("qLkw");
		setzeWert(-1, element);
		element = dataNeu.getItem("vLkw");
		setzeWert(-1, element);		
		element = dataNeu.getItem("qPkw");
		setzeWert(-1, element);
		element = dataNeu.getItem("vPkw");
		setzeWert(-1, element);				
		element = dataNeu.getItem("b");
		setzeWert(-1, element);
		element = dataNeu.getItem("sKfz");
		setzeWert(-1, element);
		element = dataNeu.getItem("vgKfz");
		setzeWert(vgkfz, element);
		element = dataNeu.getItem("aLkw");
		setzeWert(-1, element);
		element = dataNeu.getItem("kKfz");
		setzeWert(-1, element);
		element = dataNeu.getItem("kLkw");
		setzeWert(-1, element);
		element = dataNeu.getItem("kPkw");
		setzeWert(-1, element);
		element = dataNeu.getItem("qB");
		setzeWert(-1, element);
		element = dataNeu.getItem("kB");
		setzeWert(-1, element);
	}

	public static void fuelleAtgUfdsFahrBahnOberFlaechenZustand(int fbz, Data dataNeu)
	{
		dataNeu.getTimeValue("T").setSeconds(60);
		
		Data element = dataNeu.getItem("FahrBahnOberFlchenZustand");
		setzeWertUfd(fbz, element);
	}
	public static void fuelleAtgUfdsWindGeschwindigkeitMittelWert(int wgm, Data dataNeu)
	{
		dataNeu.getTimeValue("T").setSeconds(60);
		
		Data element = dataNeu.getItem("WindGeschwindigkeitMittelWert");
		setzeWertUfd(wgm, element);
	}
	public static void fuelleAtgUfdsWindRichtung(int wr, Data dataNeu)
	{
		dataNeu.getTimeValue("T").setSeconds(60);
		
		Data element = dataNeu.getItem("WindRichtung");
		setzeWertUfd(wr, element);
	}

	public static void fuelleAtgUfdsLuftschadstoffeNOx(float nox, Data dataNeu)
	{
		dataNeu.getTimeValue("T").setSeconds(60);
		
		Data element = dataNeu.getItem("StickoxideNOx");
		setzeWertUfdFloat(nox, element);
	}

	private static void setzeWert(long wert, Data element)
	{
		element.getUnscaledValue("Wert").set(wert);
		element.getItem("Status").getItem("Erfassung").getScaledValue("NichtErfasst").setText("Nein");
		element.getItem("Status").getItem("PlFormal").getScaledValue("WertMax").setText("Nein");
		element.getItem("Status").getItem("PlFormal").getScaledValue("WertMin").setText("Nein");
		element.getItem("Status").getItem("PlLogisch").getScaledValue("WertMaxLogisch").setText("Nein");
		element.getItem("Status").getItem("PlLogisch").getScaledValue("WertMinLogisch").setText("Nein");
		element.getItem("Status").getItem("MessWertErsetzung").getScaledValue("Implausibel").setText("Nein");
		element.getItem("Status").getItem("MessWertErsetzung").getScaledValue("Interpoliert").setText("Nein");		
		element.getItem("Gte").getScaledValue("Index").set(1);
		element.getItem("Gte").getScaledValue("Verfahren").setText("Standard");
	}


	private static void setzeWertUfd(int wert, Data element)
	{
		element.getUnscaledValue("Wert").set(wert);
		element.getItem("Status").getItem("Erfassung").getScaledValue("NichtErfasst").setText("Nein");
		element.getItem("Status").getItem("PlFormal").getScaledValue("WertMax").setText("Nein");
		element.getItem("Status").getItem("PlFormal").getScaledValue("WertMin").setText("Nein");
		element.getItem("Status").getItem("MessWertErsetzung").getScaledValue("Implausibel").setText("Nein");
		element.getItem("Status").getItem("MessWertErsetzung").getScaledValue("Interpoliert").setText("Nein");		
		element.getItem("Gte").getScaledValue("Index").set(1);
		element.getItem("Gte").getScaledValue("Verfahren").setText("Standard");
	}

	private static void setzeWertUfdFloat(float wert, Data element)
	{
		element.getScaledValue("Wert").set(wert);
		element.getItem("Status").getItem("Erfassung").getScaledValue("NichtErfasst").setText("Nein");
		element.getItem("Status").getItem("PlFormal").getScaledValue("WertMax").setText("Nein");
		element.getItem("Status").getItem("PlFormal").getScaledValue("WertMin").setText("Nein");
		element.getItem("Status").getItem("MessWertErsetzung").getScaledValue("Implausibel").setText("Nein");
		element.getItem("Status").getItem("MessWertErsetzung").getScaledValue("Interpoliert").setText("Nein");		
		element.getItem("Gte").getScaledValue("Index").set(1);
		element.getItem("Gte").getScaledValue("Verfahren").setText("Standard");
	}

	/**
	 * Fllt den bergebenen Datensatz mit Werten.
	 * @param dataNeu zu fllender Datensatz.
	 */
	public static void fuelleAtgParameterHarmoBelastungUnruhe120(Data dataNeu)
	{
		if (dataNeu != null)
		{
			dataNeu.getItem("1Fahrstreifen").getUnscaledValue("QBEin").set(2000);
			dataNeu.getItem("1Fahrstreifen").getUnscaledValue("QBAus").set(1800);
			dataNeu.getItem("1Fahrstreifen").getUnscaledValue("SuMax").set(20);
			dataNeu.getItem("1Fahrstreifen").getUnscaledValue("SuMin").set(15);
			dataNeu.getItem("1Fahrstreifen").getUnscaledValue("quMax").set(20);
			dataNeu.getItem("1Fahrstreifen").getUnscaledValue("quMin").set(15);
			
			dataNeu.getItem("2Fahrstreifen").getUnscaledValue("QBEin").set(3100);
			dataNeu.getItem("2Fahrstreifen").getUnscaledValue("QBAus").set(2900);
			dataNeu.getItem("2Fahrstreifen").getUnscaledValue("SuMax").set(20);
			dataNeu.getItem("2Fahrstreifen").getUnscaledValue("SuMin").set(15);
			dataNeu.getItem("2Fahrstreifen").getUnscaledValue("quMax").set(20);
			dataNeu.getItem("2Fahrstreifen").getUnscaledValue("quMin").set(15);

			dataNeu.getItem("3Fahrstreifen").getUnscaledValue("QBEin").set(4000);
			dataNeu.getItem("3Fahrstreifen").getUnscaledValue("QBAus").set(3600);
			dataNeu.getItem("3Fahrstreifen").getUnscaledValue("SuMax").set(20);
			dataNeu.getItem("3Fahrstreifen").getUnscaledValue("SuMin").set(15);
			dataNeu.getItem("3Fahrstreifen").getUnscaledValue("quMax").set(20);
			dataNeu.getItem("3Fahrstreifen").getUnscaledValue("quMin").set(15);

			dataNeu.getItem("4Fahrstreifen").getUnscaledValue("QBEin").set(4400);
			dataNeu.getItem("4Fahrstreifen").getUnscaledValue("QBAus").set(4000);
			dataNeu.getItem("4Fahrstreifen").getUnscaledValue("SuMax").set(20);
			dataNeu.getItem("4Fahrstreifen").getUnscaledValue("SuMin").set(15);
			dataNeu.getItem("4Fahrstreifen").getUnscaledValue("quMax").set(20);
			dataNeu.getItem("4Fahrstreifen").getUnscaledValue("quMin").set(15);
		}
	}	
	/**
	 * Fllt den bergebenen Datensatz mit Werten.
	 * @param dataNeu zu fllender Datensatz.
	 */
	public static void fuelleAtgKfzEinzelDatenFs(int status, int vkfz, long tnetto, Data dataNeu)
	{
		if (dataNeu != null)
		{
			dataNeu.getUnscaledValue("Status").set(status);
			dataNeu.getScaledValue("FZKlasse").setText("Lkw");
			dataNeu.getUnscaledValue("vKfz").set(vkfz);
			dataNeu.getScaledValue("Fahrtrichtung").setText("Fahrtrichtung");
			dataNeu.getScaledValue("Belegzeit").setText("12,5");
			dataNeu.getUnscaledValue("tNetto").set(tnetto);
			dataNeu.getUnscaledValue("FZLnge").set(180);			
		}
	}
	
	/**
	 * Sucht aus der Menge an dem Objekt Anlage das gltige Objekt entsprechend der
	 * bergebenen Pid und gibt es zurck.
	 * 
	 * @param connection Aktuelle Verbindung zum Datenverteiler.
	 * @param anlage Streckenbeeinflussungsanlage.
	 * @param menge Name der Menge.
	 * @param pid Pid.
	 * @return gefundenes Objekt oder <code>null<code>.
	 */
	public static SystemObject getDynObjAusMenge(ClientDavInterface connection, String anlage, String menge, String pid)
	{
		ConfigurationObject coObj = (ConfigurationObject)connection.getDataModel().getObject(anlage);
		
		List<SystemObject> objekte = coObj.getMutableSet(menge).getElements();
		if (objekte != null)
		{
			for (int i = 0; i < objekte.size(); i++)
			{
				SystemObject obj = objekte.get(i);

				if (!obj.isValid())
					continue;

				if (obj.getPid().equals(pid))
				{
//					System.out.println("Objekt aus Menge gefunden " + obj + " ID " + obj.getId() + "Valid=" + obj.isValid());
					return obj;
				}
			}
		}
		
		return null;
	}

	/**
	 * Sucht aus den in der Konfiguration vorhandenen Objekte das gltige Objekt entsprechend der
	 * bergebenen Pid und gibt es zurck.
	 * 
	 * @param connection Aktuelle Verbindung zum Datenverteiler.
	 * @param typ Objekttyp.
	 * @param pid Pid.
	 * @return gefundenes Objekt oder <code>null<code>.
	 */
	public static SystemObject getDynObjAusModell(ClientDavInterface connection, String typ, String pid)
	{
		List<SystemObject> objekte = connection.getDataModel().getType(typ).getElements();

		if (objekte != null)
		{
			for (int i = 0; i < objekte.size(); i++)
			{
				SystemObject obj = objekte.get(i);

				if (!obj.isValid())
					continue;

				if (obj.getPid().equals(pid))
				{
//					System.out.println("Objekt aus Modell gefunden " + obj + " ID " + obj.getId() + "Valid=" + obj.isValid());
					return obj;
				}
			}
		}
		
		return null;
	}
}
